@@ -23,11 +23,12 @@ class Backend:  # pylint: disable=too-many-instance-attributes
 
             test_case_id, _ = backend.test_case_get_or_create(<description>)
             backend.add_test_case_to_plan(test_case_id, backend.plan_id)
-            test_execution_id = backend.add_test_case_to_run(test_case_id,
-                                                             backend.run_id)
-            backend.update_test_execution(test_execution_id,
-                                          <status_id>,
-                                          <comment>)
+            test_executions = backend.add_test_case_to_run(test_case_id,
+                                                           backend.run_id)
+            for execution in test_executions:
+                backend.update_test_execution(execution['id'],
+                                              <status_id>,
+                                              <comment>)
 
         :param prefix: Prefix which will be added to TestPlan.name and
                        TestRun.summary
@@ -37,7 +38,6 @@ class Backend:  # pylint: disable=too-many-instance-attributes
     """
 
     _statuses = {}
-    _cases_in_test_run = {}
 
     def __init__(self, prefix=''):
         """
@@ -304,11 +304,23 @@ class Backend:  # pylint: disable=too-many-instance-attributes
     def default_tester_id(self):
         """
             Used internally and by default this is the user sending the API
-            request. Plugins may want to override this.
+            request. Use `$TCMS_DEFAULT_TESTER_ID` to override!
+
+            .. warning::
+
+                Requires ``auth.view_user`` permission if not overriden via
+                environment variable! See
+                https://kiwitcms.readthedocs.io/en/latest/admin.html?highlight=auth.view_user#managing-permissions
+
+            Plugins may want to override this.
 
             :return: User ID
             :rtype: int
         """
+        id_from_env = os.environ.get('TCMS_DEFAULT_TESTER_ID')
+        if id_from_env:
+            return id_from_env
+
         return self.rpc.User.filter()[0]['id']
 
     def get_plan_id(self, run_id):
@@ -335,9 +347,7 @@ class Backend:  # pylint: disable=too-many-instance-attributes
             product_id, product_name = self.get_product_id(0)
             version_id, version_name = self.get_version_id(product_id)
 
-            name = self.prefix + 'Plan for %s (%s)' % (product_name,
-                                                       version_name)
-
+            name = f'{self.prefix} Plan for {product_name} ({version_name})'
             result = self.rpc.TestPlan.filter({'name': name,
                                                'product': product_id,
                                                'product_version': version_id})
@@ -390,9 +400,8 @@ class Backend:  # pylint: disable=too-many-instance-attributes
             })[0]['author']
 
             testrun = self.rpc.TestRun.create({
-                'summary': self.prefix + 'Results for %s, %s, %s' % (
-                    product_name, version_val, build_number
-                ),
+                'summary': f'{self.prefix} Results for {product_name}, '
+                           f'{version_val}, {build_number}',
                 'manager': manager_id,
                 'default_tester': self.default_tester_id(),
                 'plan': plan_id,
@@ -400,11 +409,6 @@ class Backend:  # pylint: disable=too-many-instance-attributes
             })
             run_id = testrun['id']
 
-        # fetch pre-existing test cases in this TestRun
-        # used to avoid adding existing TC to TR later
-        for case in self.rpc.TestRun.get_cases(run_id):
-            self._cases_in_test_run[case['id']] = case['execution_id']
-
         return int(run_id)
 
     def finish_test_run(self):
@@ -486,13 +490,14 @@ class Backend:  # pylint: disable=too-many-instance-attributes
             :type case_id: int
             :param run_id: ``tcms.testruns.models.TestRun`` PK
             :type run_id: int
-            :return: ``tcms.testruns.models.TestExecution`` PK
-            :rtype: int
+            :return: List of serialized ``tcms.testruns.models.TestExecution``
+                objects
+            :rtype: list(dict)
         """
-        if case_id in self._cases_in_test_run.keys():
-            return self._cases_in_test_run[case_id]
-
-        return self.rpc.TestRun.add_case(run_id, case_id)['id']
+        result = self.rpc.TestRun.add_case(run_id, case_id)
+        if not isinstance(result, list):
+            result = [result]
+        return result
 
     def update_test_execution(self,
                               test_execution_id,
